@@ -37,10 +37,10 @@ sub get {
 	$self->{indel_file}   = $indel_file;
 
 
-	### Shore indel format:  sample | chromosome | begin | end | length | seq | support_type | support | concordance | uniq_prob | avg_hits
+	### Shore indel format:  sample | chromosome | begin | end | length | seq | support_type | support | concordance | avg_hits
 	open INDELFILE, $indel_file or die "Cannot open indel file: " . $indel_file . "\n";
 	while (<INDELFILE>) {
-		my ($sample, $chr, $begin, $end, $length, $seq , $support_type, $support, $concordance, $uniq_prb, $avg_hits) = split "\t";
+		my ($sample, $chr, $begin, $end, $length, $seq , $support_type, $support, $concordance, $avg_hits) = split "\t";
 
 		if ( ($chr == $chromosome) && ($begin >= $region_start) && ($end <= $region_end) ) {
 			$self->{indels}{$begin} = new Indel;
