@@ -37,10 +37,10 @@ sub get {
 	$self->{snp_file}     = $snp_file;
 
 
-	### Shore SNP format:  sample | chromosome | position | refbase | snp  | support_type | support | concordance | max_qual | rep_prob | avg_hits
+	### Shore SNP format:  sample | chromosome | position | refbase | snp  | support_type | support | concordance | max_qual | avg_hits
 	open SNPFILE, $snp_file or die "Cannot open snp file: " . $snp_file . "\n";
 	while (<SNPFILE>) {
-		my ($sample, $chr, $position, $refbase, $snp, $support_type, $support, $concordance, $max_qual, $rep_prob, $avg_hits) = split "\t";
+		my ($sample, $chr, $position, $refbase, $snp, $support_type, $support, $concordance, $max_qual, $avg_hits) = split "\t";
 
 		if ( ($chr == $chromosome) && ($position >= $region_start) && ($position <= $region_end) ) {
 			$self->{snps}{$position} = new SNP();
